@@ -1,6 +1,10 @@
-"""Worker task for resolving location data from openstreetmap.
+"""Helpers for resolving hierarchical location data from openstreetmap.
 
 Adds location and its parent relations to database.
+
+.. moduleauthor:: Louis Holbrook <dev@holbrook.no>
+
+.. todo:: Translate to sphinx docstring
 """
 
 # standard imports
